@@ -1,4 +1,4 @@
-/*PGR*********************************************************************
+/*PGR-MIT******************************************************************
  *
  * file pgr_assert.cpp
  *
@@ -6,9 +6,9 @@
  * Copyright 2014 Vicky Vergara <vicky_vergara@hotmail.com>
  *
  * This is free software; you can redistribute and/or modify it under
- * the terms of the MIT License. Please file LICENSE for details.
+ * the terms of the MIT License. Please file MIT-LICENSE for details.
  *
- ********************************************************************PGR*/
+ *****************************************************************PGR-MIT*/
 #include "./pgr_assert.h"
 #include <exception>
 
@@ -27,7 +27,7 @@ const char *AssertFailedException::what() const throw() {
   return str;
 }
 
-AssertFailedException::AssertFailedException(const char *_str) : str(
-    _str ) {}
+AssertFailedException::AssertFailedException(const char *_str) :
+    str(_str) {}
 
 
