@@ -1,7 +1,9 @@
-/*PGR
+/*PGR-GNU*****************************************************************
+File: ksp.h
 
 Copyright (c) 2015 Celia Virginia Vergara Castillo
-vicky_vergara@hotmail.com
+Mail: vicky_vergara@hotmail.com
+------
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,17 +19,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-*/
+********************************************************************PGR-GNU*/
 
-
-#ifndef SRC_KSP_SRC_KSP_H_
-#define SRC_KSP_SRC_KSP_H_
-
-// #define TUPLIMIT 1000
-// #define PATH_ALLOC_TOTAL 5
-
-// #include <unistd.h>
-// #include "postgres.h"
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -36,13 +30,12 @@ extern "C" {
 
 #include "./../../common/src/pgr_types.h"
 
-int compute(char* sql, int64_t start_vertex,
+    int compute(char* sql, int64_t start_vertex,
             int64_t end_vertex, int no_paths,
             bool has_reverse_cost, bool directedFlag,
-            pgr_path_element3_t **path, int *ksp_path_count);
+            General_path_element_t **path, size_t *ksp_path_count);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif  // SRC_KSP_SRC_KSP_H_
