@@ -1,7 +1,10 @@
-/*PGR
+/*PGR-GNU*****************************************************************
+File: ksp_driver.h
 
 Copyright (c) 2015 Celia Virginia Vergara Castillo
-vicky_vergara@hotmail.com
+Mail: vicky_vergara@hotmail.com
+
+------
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,28 +20,23 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-*/
+********************************************************************PGR-GNU*/
 
-#ifndef SRC_KSP_SRC_KSP_DRIVER_H_
-#define SRC_KSP_SRC_KSP_DRIVER_H_
-
-// #include <stdarg.h>
-// #include <stdio.h>
-
-#include "./../../common/src/pgr_types.h"
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-int  do_pgr_ksp(pgr_edge_t  * edges, int64_t total_tuples,
-                      int64_t  start_vertex, int64_t end_vertex,
-                      int no_paths, bool has_reverse_cost, bool directed,
-                      pgr_path_element3_t **ksp_path, int *path_count,
-                      char ** err_msg);
+#include "./../../common/src/pgr_types.h"
+
+    int  do_pgr_ksp(pgr_edge_t  * edges, size_t total_tuples,
+            int64_t  start_vertex, int64_t end_vertex,
+            int no_paths, bool directed, bool heap_paths,
+            General_path_element_t **ksp_path, size_t *path_count,
+            char ** err_msg);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif  // SRC_KSP_SRC_KSP_DRIVER_H_
