@@ -1,3 +1,25 @@
+/*PGR-GNU*****************************************************************
+
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
+------
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+********************************************************************PGR-GNU*/
 
 #ifdef __MINGW32__
 #include <winsock2.h>
@@ -5,31 +27,35 @@
 #endif
 
 
+#include <sstream>
 #include "GraphDefinition.h"
 
 // -------------------------------------------------------------------------
-GraphDefinition::GraphDefinition(void)
-{
-    m_lStartEdgeId = -1;
-    m_lEndEdgeId = 0;
-    m_dStartpart = 0.0;
-    m_dEndPart = 0.0;
-    m_dCost = NULL;
-    m_bIsturnRestrictOn = false;
-    m_bIsGraphConstructed = false;
-    parent = NULL;
-    init();
-}
+GraphDefinition::GraphDefinition(
+        edge_t *edges,
+        unsigned int edge_count,
+        bool directed,
+        bool has_rcost) :
+    m_lStartEdgeId(-1),
+    m_lEndEdgeId(0),
+    m_dStartpart(0.0),
+    m_dEndPart(0.0),
+    m_edge_count(edge_count),
+    m_bIsturnRestrictOn(false),
+    m_bIsGraphConstructed(false) {
+        m_dCost.clear();
+        parent.clear();
+        init();
+        construct_graph(edges, has_rcost, directed);
+        m_bIsGraphConstructed = true;
+    }
 
 // -------------------------------------------------------------------------
-GraphDefinition::~GraphDefinition(void)
-{
-}
+GraphDefinition::~GraphDefinition(void) { }
 
 
 // -------------------------------------------------------------------------
-void GraphDefinition::init()
-{
+void GraphDefinition::init() {
     max_edge_id = 0;
     max_node_id = 0;
     isStartVirtual = false;
@@ -38,33 +64,26 @@ void GraphDefinition::init()
 
 
 // -------------------------------------------------------------------------
-void GraphDefinition::deleteall()
-{
-    std::vector<GraphEdgeInfo*>::iterator it;
-    for(it  = m_vecEdgeVector.begin(); it != m_vecEdgeVector.end(); it++){
-        delete *it;
-    }
+
+void GraphDefinition::deleteall() {
     m_vecEdgeVector.clear();
 
-    delete [] parent;
-    delete [] m_dCost;
+    parent.clear();
+    m_dCost.clear();
 }
 
 
+
+
 // -------------------------------------------------------------------------
-double GraphDefinition::construct_path(int ed_id, int v_pos)
-{
-    if(parent[ed_id].ed_ind[v_pos] == -1)
-    {
+double GraphDefinition::construct_path(int64_t ed_id, int64_t v_pos) {
+    if(parent[ed_id].ed_ind[v_pos] == -1) {
         path_element_t pelement;
-        GraphEdgeInfo* cur_edge = m_vecEdgeVector[ed_id];
-        if(v_pos == 0)
-        {
+        GraphEdgeInfo* cur_edge = &m_vecEdgeVector[ed_id];
+        if(v_pos == 0) {
             pelement.vertex_id = cur_edge->m_lStartNode;
             pelement.cost = cur_edge->m_dCost;
-        }
-        else
-        {
+        } else {
             pelement.vertex_id = cur_edge->m_lEndNode;
             pelement.cost = cur_edge->m_dReverseCost;
         }
@@ -75,15 +94,12 @@ double GraphDefinition::construct_path(int ed_id, int v_pos)
     }
     double ret = construct_path(parent[ed_id].ed_ind[v_pos], parent[ed_id].v_pos[v_pos]);
     path_element_t pelement;
-    GraphEdgeInfo* cur_edge = m_vecEdgeVector[ed_id];
-    if(v_pos == 0)
-    {
+    GraphEdgeInfo* cur_edge = &m_vecEdgeVector[ed_id];
+    if(v_pos == 0) {
         pelement.vertex_id = cur_edge->m_lStartNode;
         pelement.cost = m_dCost[ed_id].endCost - ret;// cur_edge.m_dCost;
         ret = m_dCost[ed_id].endCost;
-    }
-    else
-    {
+    } else {
         pelement.vertex_id = cur_edge->m_lEndNode;
         pelement.cost = m_dCost[ed_id].startCost - ret;
         ret = m_dCost[ed_id].startCost;
@@ -98,44 +114,36 @@ double GraphDefinition::construct_path(int ed_id, int v_pos)
 
 // -------------------------------------------------------------------------
 double GraphDefinition::getRestrictionCost(
-    int edge_ind,
-    GraphEdgeInfo& new_edge,
-    bool isStart)
-{
+        int64_t edge_ind,
+        GraphEdgeInfo& new_edge,
+        bool isStart) {
     double cost = 0.0;
-    int edge_id = new_edge.m_lEdgeID;
-    if(m_ruleTable.find(edge_id) == m_ruleTable.end())
-    {    
+    auto edge_id = new_edge.m_lEdgeID;
+    if(m_ruleTable.find(edge_id) == m_ruleTable.end()) {    
         return(0.0);
     }
     std::vector<Rule> vecRules = m_ruleTable[edge_id];
-    int ruleIndex;
-    int totalRule = vecRules.size();
-    int st_edge_ind = edge_ind;
-    for(ruleIndex = 0; ruleIndex < totalRule; ruleIndex++)
-    {
+    auto totalRule = vecRules.size();
+    auto st_edge_ind = edge_ind;
+    for(size_t ruleIndex = 0; ruleIndex < totalRule; ruleIndex++) {
         bool flag = true;
-        int total_edge = vecRules[ruleIndex].precedencelist.size();
-        int i;
-        int v_pos = (isStart?0:1);
+        auto total_edge = vecRules[ruleIndex].precedencelist.size();
+        int64_t v_pos = (isStart?0:1);
         edge_ind = st_edge_ind;
-        for(i = 0; i < total_edge; i++)
-        {
-            if(edge_ind == -1)
-            {
+        for(size_t i = 0; i < total_edge; i++) {
+            if(edge_ind == -1) {
                 flag = false;
                 break;
             }
-            if(vecRules[ruleIndex].precedencelist[i] != m_vecEdgeVector[edge_ind]->m_lEdgeID)
-            {
+            if(vecRules[ruleIndex].precedencelist[i] != m_vecEdgeVector[edge_ind].m_lEdgeID) {
                 flag = false;
                 break;
             }
-            int parent_ind = parent[edge_ind].ed_ind[v_pos];
+            auto parent_ind = parent[edge_ind].ed_ind[v_pos];
             v_pos = parent[edge_ind].v_pos[v_pos];
             edge_ind = parent_ind;
         }
-        if(flag)
+        if(flag) 
             cost += vecRules[ruleIndex].cost;
     }
     return cost;
@@ -144,60 +152,52 @@ double GraphDefinition::getRestrictionCost(
 
 // -------------------------------------------------------------------------
 void GraphDefinition::explore(
-    int cur_node,
-    GraphEdgeInfo& cur_edge,
-    bool isStart,
-    LongVector &vecIndex,
-    std::priority_queue<PDP, std::vector<PDP>,
-    std::greater<PDP> > &que)
-{
+        int64_t cur_node,
+        GraphEdgeInfo &cur_edge,
+        bool isStart,
+        LongVector &vecIndex,
+        std::priority_queue<PDP, std::vector<PDP>,
+        std::greater<PDP> > &que) {
     unsigned int i;
     double extCost = 0.0;
-    GraphEdgeInfo* new_edge;
+    GraphEdgeInfo new_edge;
     // int new_node;
     double totalCost;
-    for(i = 0; i < vecIndex.size(); i++)
-    {
+    for(i = 0; i < vecIndex.size(); i++) {
         new_edge = m_vecEdgeVector[vecIndex[i]];
         extCost = 0.0;
-        if(m_bIsturnRestrictOn)
-        {
-            extCost = getRestrictionCost(cur_edge.m_lEdgeIndex, *new_edge, isStart);
+        if(m_bIsturnRestrictOn) {
+            extCost = getRestrictionCost(cur_edge.m_lEdgeIndex, new_edge, isStart);
         }
-        if(new_edge->m_lStartNode == cur_node)
-        {
-            if(new_edge->m_dCost >= 0.0)
-            {
+        if(new_edge.m_lStartNode == cur_node) {
+            if(new_edge.m_dCost >= 0.0) {
                 //new_node = new_edge->m_lEndNode;
-                
+
                 if(isStart)
-                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].endCost + new_edge->m_dCost + extCost;
+                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].endCost + new_edge.m_dCost + extCost;
                 else
-                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].startCost + new_edge->m_dCost + extCost;
-                if(totalCost < m_dCost[vecIndex[i]].endCost)
-                {
+                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].startCost + new_edge.m_dCost + extCost;
+                if(totalCost < m_dCost[vecIndex[i]].endCost) {
                     m_dCost[vecIndex[i]].endCost = totalCost;
-                    parent[new_edge->m_lEdgeIndex].v_pos[0] = (isStart?0:1);
-                    parent[new_edge->m_lEdgeIndex].ed_ind[0] = cur_edge.m_lEdgeIndex;
-                    que.push(std::make_pair(totalCost, std::make_pair(new_edge->m_lEdgeIndex, true)));
+                    parent[new_edge.m_lEdgeIndex].v_pos[0] = (isStart?0:1);
+                    parent[new_edge.m_lEdgeIndex].ed_ind[0] = cur_edge.m_lEdgeIndex;
+                    que.push(std::make_pair(totalCost, std::make_pair(new_edge.m_lEdgeIndex, true)));
                 }
             }
-        }
-        else
-        {
-            if(new_edge->m_dReverseCost >= 0.0)
+        } else {
+            if(new_edge.m_dReverseCost >= 0.0)
             {
                 // new_node = new_edge->m_lStartNode;
                 if(isStart)
-                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].endCost + new_edge->m_dReverseCost + extCost;
+                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].endCost + new_edge.m_dReverseCost + extCost;
                 else
-                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].startCost + new_edge->m_dReverseCost + extCost;
+                    totalCost = m_dCost[cur_edge.m_lEdgeIndex].startCost + new_edge.m_dReverseCost + extCost;
                 if(totalCost < m_dCost[vecIndex[i]].startCost)
                 {
                     m_dCost[vecIndex[i]].startCost = totalCost;
-                    parent[new_edge->m_lEdgeIndex].v_pos[1] = (isStart?0:1);
-                    parent[new_edge->m_lEdgeIndex].ed_ind[1] = cur_edge.m_lEdgeIndex;
-                    que.push(std::make_pair(totalCost, std::make_pair(new_edge->m_lEdgeIndex, false)));
+                    parent[new_edge.m_lEdgeIndex].v_pos[1] = (isStart?0:1);
+                    parent[new_edge.m_lEdgeIndex].ed_ind[1] = cur_edge.m_lEdgeIndex;
+                    que.push(std::make_pair(totalCost, std::make_pair(new_edge.m_lEdgeIndex, false)));
                 }
             }
         }
@@ -205,211 +205,15 @@ void GraphDefinition::explore(
 }
 
 
-// -------------------------------------------------------------------------
-int GraphDefinition::multi_dijkstra(
-    edge_t *edges,
-    unsigned int edge_count,
-    std::vector<int> vertices,
-    bool directed,
-    bool has_reverse_cost, 
-    path_element_t **path,
-    int *path_count,
-    char **err_msg,
-    std::vector<PDVI> &ruleList)
-{
-    construct_graph(edges, edge_count, has_reverse_cost, directed);
-    if(ruleList.size() > 0)
-    {
-    m_ruleTable.clear();
-    int total_rule = ruleList.size();
-    int i;
-    LongVector vecsource;
-    // int kk;
-    for(i = 0; i < total_rule; i++)
-    {
-        Rule rule;
-        rule.cost = ruleList[i].first;
-        int j;
-        int seq_cnt = ruleList[i].second.size();
-        for(j = 1; j < seq_cnt; j++)
-        {
-            rule.precedencelist.push_back(ruleList[i].second[j]);
-        }
-        int dest_edge_id = ruleList[i].second[0];
-        if(m_ruleTable.find(dest_edge_id) != m_ruleTable.end())
-        {
-            m_ruleTable[dest_edge_id].push_back(rule);
-        }
-        else
-        {
-            std::vector<Rule> temprules;
-            temprules.clear();
-            temprules.push_back(rule);
-            m_ruleTable.insert(std::make_pair(dest_edge_id, temprules));
-        }
-    }
-    
-    m_bIsturnRestrictOn = true;
-    }
-    parent = new PARENT_PATH[edge_count + 1];
-    m_dCost = new CostHolder[edge_count + 1];
-    m_vecPath.clear();
-    int i;
-    int total_vertices = vertices.size();
-    for(i = 0; i < total_vertices - 1; i++)
-    {
-    int ret = my_dijkstra(vertices[i], vertices[i + 1], edge_count, err_msg);
-    if(ret < 0)
-    {
-        deleteall();
-        return -1;
-    }
-    }
-
-    *path = (path_element_t *) malloc(sizeof(path_element_t) * (m_vecPath.size() + 1));
-    *path_count = m_vecPath.size();
-
-    for(i = 0; i < *path_count; i++)
-    {
-    (*path)[i].vertex_id = m_vecPath[i].vertex_id;
-    (*path)[i].edge_id = m_vecPath[i].edge_id;
-    (*path)[i].cost = m_vecPath[i].cost;
-    }
-    deleteall();
-    return 0;
-}
-
 
 // -------------------------------------------------------------------------
-int GraphDefinition::my_dijkstra(int start_vertex, int end_vertex, unsigned int edge_count, char **err_msg)
+    void
+GraphDefinition::add_virtual_vertices(int start_edge_id, double start_part, int end_edge_id, double end_part,
+        int64_t &start_vertex, int64_t &end_vertex)
 {
-    if(!m_bIsGraphConstructed)
-    {
-    *err_msg = (char *)"Graph not Ready!";
-    return -1;
-    }
-    unsigned int i;
-    for(i = 0; i <= edge_count; i++)
-    {
-    m_dCost[i].startCost = 1e15;
-    m_dCost[i].endCost = 1e15;
-    }
-
-    if(m_mapNodeId2Edge.find(start_vertex) == m_mapNodeId2Edge.end())
-    {
-    *err_msg = (char *)"Source Not Found";
-    deleteall();
-    return -1;
-    }
-
-    if(m_mapNodeId2Edge.find(end_vertex) == m_mapNodeId2Edge.end())
-    {
-    *err_msg = (char *)"Destination Not Found";
-    deleteall();
-    return -1;
-    }
-
-    std::priority_queue<PDP, std::vector<PDP>, std::greater<PDP> > que;
-    LongVector vecsource = m_mapNodeId2Edge[start_vertex];
-    GraphEdgeInfo* cur_edge = NULL;
-
-    for(i = 0; i < vecsource.size(); i++)
-    {
-    cur_edge = m_vecEdgeVector[vecsource[i]];
-    if(cur_edge->m_lStartNode == start_vertex)
-    {
-        if(cur_edge->m_dCost >= 0.0)
-        {
-        m_dCost[cur_edge->m_lEdgeIndex].endCost= cur_edge->m_dCost;
-        parent[cur_edge->m_lEdgeIndex].v_pos[0] = -1;
-        parent[cur_edge->m_lEdgeIndex].ed_ind[0] = -1;
-        que.push(std::make_pair(cur_edge->m_dCost, std::make_pair(cur_edge->m_lEdgeIndex, true)));
-        }
-    }
-    else
-    {
-        if(cur_edge->m_dReverseCost >= 0.0)
-        {
-        m_dCost[cur_edge->m_lEdgeIndex].startCost = cur_edge->m_dReverseCost;
-        parent[cur_edge->m_lEdgeIndex].v_pos[1] = -1;
-        parent[cur_edge->m_lEdgeIndex].ed_ind[1] = -1;
-        que.push(std::make_pair(cur_edge->m_dReverseCost, std::make_pair(cur_edge->m_lEdgeIndex, false)));
-        }
-    }
-    }
-    
-    // int new_node;
-    int cur_node = -1;
-
-    while(!que.empty())
-    {
-    PDP cur_pos = que.top();
-    que.pop();
-    int cured_index = cur_pos.second.first;
-    cur_edge = m_vecEdgeVector[cured_index];
-    //GraphEdgeInfo* new_edge;
-
-    if(cur_pos.second.second)      // explore edges connected to end node
-    {
-        cur_node = cur_edge->m_lEndNode;
-        if(cur_edge->m_dCost < 0.0)
-        continue;
-        if(cur_node == end_vertex)
-        break;
-        explore(cur_node, *cur_edge, true, cur_edge->m_vecEndConnedtedEdge, que);
-    }
-    else        // explore edges connected to start node
-    {
-        cur_node = cur_edge->m_lStartNode;
-        if(cur_edge->m_dReverseCost < 0.0)
-        continue;
-        if(cur_node == end_vertex)
-        break;
-        explore(cur_node, *cur_edge, false, cur_edge->m_vecStartConnectedEdge, que);
-    }
-    }
-    if(cur_node != end_vertex)
-    {
-    *err_msg = (char *)"Path Not Found";
-    deleteall();
-    return -1;
-    }
-    else
-    {
-    // double total_cost;  //set but not used
-    if(cur_node == cur_edge->m_lStartNode)
-    {
-        // total_cost = m_dCost[cur_edge->m_lEdgeIndex].startCost;
-        construct_path(cur_edge->m_lEdgeIndex, 1);
-    }
-    else
-    {
-        // total_cost = m_dCost[cur_edge->m_lEdgeIndex].endCost;
-        construct_path(cur_edge->m_lEdgeIndex, 0);
-    }
-    path_element_t pelement;
-    pelement.vertex_id = end_vertex;
-    pelement.edge_id = -1;
-    pelement.cost = 0.0;
-    m_vecPath.push_back(pelement);
-    }
-    return 0;
-}
-
-
-// -------------------------------------------------------------------------
-int GraphDefinition::my_dijkstra(edge_t *edges, unsigned int edge_count, int start_edge_id, double start_part, int end_edge_id, double end_part, bool directed, bool has_reverse_cost,
-                path_element_t **path, int *path_count, char **err_msg, std::vector<PDVI> &ruleList)
-{
-    if(!m_bIsGraphConstructed)
-    {
-        init();
-        construct_graph(edges, edge_count, has_reverse_cost, directed);
-        m_bIsGraphConstructed = true;
-    }
-    GraphEdgeInfo* start_edge_info = m_vecEdgeVector[m_mapEdgeId2Index[start_edge_id]];
+    GraphEdgeInfo *start_edge_info = &m_vecEdgeVector[m_mapEdgeId2Index[start_edge_id]];
     edge_t start_edge;
-    int start_vertex, end_vertex;
+    //int start_vertex, end_vertex;
     m_dStartpart = start_part;
     m_dEndPart = end_part;
     m_lStartEdgeId = start_edge_id;
@@ -438,7 +242,7 @@ int GraphDefinition::my_dijkstra(edge_t *edges, unsigned int edge_count, int sta
             start_edge.target = start_edge_info->m_lEndNode;
             start_edge.cost = (1.0 - start_part) * start_edge_info->m_dCost;
             addEdge(start_edge);
-            edge_count++;
+            m_edge_count++;
         }
         if(start_edge_info->m_dReverseCost >= 0.0)
         {
@@ -447,13 +251,13 @@ int GraphDefinition::my_dijkstra(edge_t *edges, unsigned int edge_count, int sta
             start_edge.target = start_edge_info->m_lStartNode;
             start_edge.cost = start_part * start_edge_info->m_dReverseCost;
             addEdge(start_edge);
-            edge_count++;
+            m_edge_count++;
         }
     }
 
-    GraphEdgeInfo* end_edge_info = m_vecEdgeVector[m_mapEdgeId2Index[end_edge_id]];
+    GraphEdgeInfo *end_edge_info = &m_vecEdgeVector[m_mapEdgeId2Index[end_edge_id]];
     edge_t end_edge;
-    
+
     if(end_part == 0.0)
     {
         end_vertex = end_edge_info->m_lStartNode;
@@ -477,7 +281,7 @@ int GraphDefinition::my_dijkstra(edge_t *edges, unsigned int edge_count, int sta
             end_edge.source = end_edge_info->m_lStartNode;
             end_edge.cost = end_part * end_edge_info->m_dCost;
             addEdge(end_edge);
-            edge_count++;
+            m_edge_count++;
         }
         if(end_edge_info->m_dReverseCost >= 0.0)
         {
@@ -485,120 +289,98 @@ int GraphDefinition::my_dijkstra(edge_t *edges, unsigned int edge_count, int sta
             end_edge.id = max_edge_id + 1;
             end_edge.cost = (1.0 - end_part) * end_edge_info->m_dReverseCost;
             addEdge(end_edge);
-            edge_count++;
+            m_edge_count++;
         }
     }
-
-    return(my_dijkstra(edges, edge_count, start_vertex, end_vertex, directed, has_reverse_cost, path, path_count, err_msg, ruleList));
+    //edge_count = m_edge_count;
 }
 
 
 // -------------------------------------------------------------------------
-int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int start_vertex, int end_vertex, bool directed, bool has_reverse_cost,
-                                  path_element_t **path, int *path_count, char **err_msg, std::vector<PDVI> &ruleList)
-{
+    void
+GraphDefinition::set_restrictions(
+        int64_t start_vertex,
+        int64_t end_vertex,
+        std::vector<PDVI> &ruleList) {
     m_ruleTable.clear();
-    int total_rule = ruleList.size();
-    int i;
+    auto total_rule = ruleList.size();
     LongVector vecsource;
     unsigned int kk;
-    for(i = 0; i < total_rule; i++)
+    for(size_t i = 0; i < total_rule; i++)
     {
         Rule rule;
         rule.cost = ruleList[i].first;
-        int j;
-        int seq_cnt = ruleList[i].second.size();
-        for(j = 1; j < seq_cnt; j++)
-        {
+        auto seq_cnt = ruleList[i].second.size();
+        for(size_t j = 1; j < seq_cnt; j++) {
             rule.precedencelist.push_back(ruleList[i].second[j]);
         }
-        int dest_edge_id = ruleList[i].second[0];
-        if(m_ruleTable.find(dest_edge_id) != m_ruleTable.end())
-        {
+        auto dest_edge_id = ruleList[i].second[0];
+        if(m_ruleTable.find(dest_edge_id) != m_ruleTable.end()) {
             m_ruleTable[dest_edge_id].push_back(rule);
-        }
-        else
-        {
+        } else {
             std::vector<Rule> temprules;
             temprules.clear();
             temprules.push_back(rule);
             m_ruleTable.insert(std::make_pair(dest_edge_id, temprules));
         }
-    
-        if(isStartVirtual)
-        {
-            if(seq_cnt == 2 && ruleList[i].second[1] == m_lStartEdgeId)
-            {
+
+        if(isStartVirtual) {
+            if(seq_cnt == 2 && ruleList[i].second[1] == m_lStartEdgeId) {
                 vecsource = m_mapNodeId2Edge[start_vertex];
-                for(kk = 0; kk < vecsource.size(); kk++)
-                {
+                for(kk = 0; kk < vecsource.size(); kk++) {
                     rule.precedencelist.clear();
-                    rule.precedencelist.push_back(m_vecEdgeVector[vecsource[kk]]->m_lEdgeID);
+                    rule.precedencelist.push_back(m_vecEdgeVector[vecsource[kk]].m_lEdgeID);
                     m_ruleTable[dest_edge_id].push_back(rule);
                 }
             }
         }
     }
-    if(isEndVirtual)
-    {
-        if(m_ruleTable.find(m_lEndEdgeId) != m_ruleTable.end())
-        {
+    if(isEndVirtual) {
+        if(m_ruleTable.find(m_lEndEdgeId) != m_ruleTable.end()) {
             std::vector<Rule> tmpRules = m_ruleTable[m_lEndEdgeId];
             vecsource = m_mapNodeId2Edge[end_vertex];
-            for(kk = 0; kk < vecsource.size(); kk++)
-            {
-                m_ruleTable.insert(std::make_pair(m_vecEdgeVector[vecsource[kk]]->m_lEdgeID, tmpRules));
+            for(kk = 0; kk < vecsource.size(); kk++) {
+                m_ruleTable.insert(std::make_pair(m_vecEdgeVector[vecsource[kk]].m_lEdgeID, tmpRules));
             }
         }
     }
     m_bIsturnRestrictOn = true;
-    return(my_dijkstra(edges, edge_count, start_vertex, end_vertex, directed, has_reverse_cost, path, path_count, err_msg));
 }
 
-
+// THIS ONE IS THE DIJKSTRA
 // -------------------------------------------------------------------------
-int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int start_vertex, int end_vertex, bool directed, bool has_reverse_cost,
-                path_element_t **path, int *path_count, char **err_msg)
-{
-    if(!m_bIsGraphConstructed)
-    {
-        init();
-        construct_graph(edges, edge_count, has_reverse_cost, directed);
-        m_bIsGraphConstructed = true;
-    }
-    
+int GraphDefinition:: my_dijkstra(int64_t start_vertex, int64_t end_vertex,
+        path_element_t **path, size_t *path_count,
+        std::ostringstream &log) {
+
     std::priority_queue<PDP, std::vector<PDP>, std::greater<PDP> > que;
-    parent = new PARENT_PATH[edge_count + 1];
-    m_dCost = new CostHolder[edge_count + 1];
+    parent.resize(m_edge_count + 1);
+    m_dCost.resize(m_edge_count + 1);
     m_vecPath.clear();
 
-    unsigned int i;
-    for(i = 0; i <= edge_count; i++)
-    {
-        m_dCost[i].startCost = 1e15;
-        m_dCost[i].endCost = 1e15;
+    for (auto &dcost : m_dCost) {
+        dcost.startCost = 1e15;
+        dcost.endCost = 1e15;
     }
-    
+
     if(m_mapNodeId2Edge.find(start_vertex) == m_mapNodeId2Edge.end())
     {
-        *err_msg = (char *)"Source Not Found";
-        deleteall();
+        log << "Source Not Found";
         return -1;
     }
 
     if(m_mapNodeId2Edge.find(end_vertex) == m_mapNodeId2Edge.end())
     {
-        *err_msg = (char *)"Destination Not Found";
-        deleteall();
+        log << "Destination Not Found";
         return -1;
     }
 
     LongVector vecsource = m_mapNodeId2Edge[start_vertex];
-    GraphEdgeInfo* cur_edge = NULL;
+    GraphEdgeInfo *cur_edge = NULL;
 
-    for(i = 0; i < vecsource.size(); i++)
+    for (auto &s : vecsource)
     {
-        cur_edge = m_vecEdgeVector[vecsource[i]];
+        GraphEdgeInfo *cur_edge = &m_vecEdgeVector[s];
         if(cur_edge->m_lStartNode == start_vertex)
         {
             if(cur_edge->m_dCost >= 0.0)
@@ -608,9 +390,7 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int st
                 parent[cur_edge->m_lEdgeIndex].ed_ind[0] = -1;
                 que.push(std::make_pair(cur_edge->m_dCost, std::make_pair(cur_edge->m_lEdgeIndex, true)));
             }
-        }
-        else
-        {
+        } else {
             if(cur_edge->m_dReverseCost >= 0.0)
             {
                 m_dCost[cur_edge->m_lEdgeIndex].startCost = cur_edge->m_dReverseCost;
@@ -620,32 +400,25 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int st
             }
         }
     }
-    //parent[start_vertex].v_id = -1;
-    //parent[start_vertex].ed_id = -1;
-    //m_dCost[start_vertex] = 0.0;
 
-    // int new_node;
-    int cur_node = -1;
+    int64_t cur_node = -1;
 
-    while(!que.empty())
-    {
+    while(!que.empty()) {
         PDP cur_pos = que.top();
         que.pop();
         int cured_index = cur_pos.second.first;
-        cur_edge = m_vecEdgeVector[cured_index];
-        //GraphEdgeInfo* new_edge;
+        cur_edge = &m_vecEdgeVector[cured_index];
 
-        if(cur_pos.second.second)      // explore edges connected to end node
-        {
+        if(cur_pos.second.second) {
+            // explore edges connected to end node
             cur_node = cur_edge->m_lEndNode;
             if(cur_edge->m_dCost < 0.0)
                 continue;
             if(cur_node == end_vertex)
                 break;
             explore(cur_node, *cur_edge, true, cur_edge->m_vecEndConnedtedEdge, que);
-        }
-        else        // explore edges connected to start node
-        {
+        } else {
+            // explore edges connected to start node
             cur_node = cur_edge->m_lStartNode;
             if(cur_edge->m_dReverseCost < 0.0)
                 continue;
@@ -654,29 +427,22 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int st
             explore(cur_node, *cur_edge, false, cur_edge->m_vecStartConnectedEdge, que);
         }
     }
-    if(cur_node != end_vertex)
-    {
-        if(m_lStartEdgeId == m_lEndEdgeId)
-        {
-            if(get_single_cost(1000.0, path, path_count))
-            {
+    if(cur_node != end_vertex) {
+        if(m_lStartEdgeId == m_lEndEdgeId) {
+            if(get_single_cost(1000.0, path, path_count)) {
                 return 0;
             }
         }
-        *err_msg = (char *)"Path Not Found";
-        deleteall();
-        return -1;
-    }
-    else
-    {
+        log << "Path Not Found";
+        *path=NULL;
+        path_count=0;
+        return 0;
+    } else {
         double total_cost;
-        if(cur_node == cur_edge->m_lStartNode)
-        {
+        if(cur_node == cur_edge->m_lStartNode) {
             total_cost = m_dCost[cur_edge->m_lEdgeIndex].startCost;
             construct_path(cur_edge->m_lEdgeIndex, 1);
-        }
-        else
-        {
+        } else {
             total_cost = m_dCost[cur_edge->m_lEdgeIndex].endCost;
             construct_path(cur_edge->m_lEdgeIndex, 0);
         }
@@ -693,11 +459,11 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int st
                 return 0;
             }
         }
-        
+
         *path = (path_element_t *) malloc(sizeof(path_element_t) * (m_vecPath.size() + 1));
         *path_count = m_vecPath.size();
 
-        for(int i = 0; i < *path_count; i++)
+        for(size_t i = 0; i < *path_count; i++)
         {
             (*path)[i].vertex_id = m_vecPath[i].vertex_id;
             (*path)[i].edge_id = m_vecPath[i].edge_id;
@@ -714,15 +480,14 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, unsigned int edge_count, int st
             (*path)[*path_count - 1].edge_id = m_lEndEdgeId;
         }
     }
-    deleteall();
     return 0;
 }
 
 
 // -------------------------------------------------------------------------
-bool GraphDefinition::get_single_cost(double total_cost, path_element_t **path, int *path_count)
+bool GraphDefinition::get_single_cost(double total_cost, path_element_t **path, size_t *path_count)
 {
-    GraphEdgeInfo* start_edge_info = m_vecEdgeVector[m_mapEdgeId2Index[m_lStartEdgeId]];
+    GraphEdgeInfo *start_edge_info = &m_vecEdgeVector[m_mapEdgeId2Index[m_lStartEdgeId]];
     if(m_dEndPart >= m_dStartpart)
     {
         if(start_edge_info->m_dCost >= 0.0 && start_edge_info->m_dCost * (m_dEndPart - m_dStartpart) <= total_cost)
@@ -750,27 +515,51 @@ bool GraphDefinition::get_single_cost(double total_cost, path_element_t **path,
         }
     }
     return false;
-    
+
 }
 
 
 // -------------------------------------------------------------------------
-bool GraphDefinition::construct_graph(edge_t* edges, int edge_count, bool has_reverse_cost, bool directed)
-{
-    int i;
-    for(i = 0; i < edge_count; i++)
-    {
-        if(!has_reverse_cost)
-        {
-        if(directed)
-        {
+bool GraphDefinition::construct_graph(edge_t* edges, bool has_reverse_cost, bool directed) {
+    unsigned int i;
+    for(i = 0; i < m_edge_count; i++) {
+
+        /*
+         *  has_reverse_cost but cost is negative
+         *    - flip the record
+         *    - After this: cost is positive unless reverse_cost was also negative
+         */
+        if (has_reverse_cost) {
+            if (edges[i].cost < 0) {
+                auto tmp_v = edges[i].source;
+                edges[i].source = edges[i].target;
+                edges[i].target = tmp_v;
+                edges[i].cost = edges[i].reverse_cost;
+                edges[i].reverse_cost = -1.0;
+            }
+        }
+
+        /*
+         * all data in the reverse_cost column must be ignored
+         */
+        if (!has_reverse_cost) {
             edges[i].reverse_cost = -1.0;
         }
-        else
-        {
+
+        /* 
+         * when the graph is undirected:
+         * both colummns must have the same smallest positive value
+         */
+        if (!directed && !has_reverse_cost) {
             edges[i].reverse_cost = edges[i].cost;
+        } else if (!directed && has_reverse_cost) {
+            if (edges[i].reverse_cost < 0) {
+                edges[i].reverse_cost = edges[i].cost;
+            } else {
+                edges[i].reverse_cost = std::min(edges[i].reverse_cost, edges[i].cost);
+            }
         }
-        }
+
         addEdge(edges[i]);
     }
     m_bIsGraphConstructed = true;
@@ -824,30 +613,26 @@ bool GraphDefinition::addEdge(edge_t edgeIn)
     if(itMap != m_mapEdgeId2Index.end())    
         return false;
 
-    
-    GraphEdgeInfo* newEdge = new GraphEdgeInfo();
-    newEdge->m_vecStartConnectedEdge.clear();
-    newEdge->m_vecEndConnedtedEdge.clear();
-    newEdge->m_vecRestrictedEdge.clear();
-    newEdge->m_lEdgeID = edgeIn.id;
-    newEdge->m_lEdgeIndex = m_vecEdgeVector.size();    
-    newEdge->m_lStartNode = edgeIn.source;
-    newEdge->m_lEndNode = edgeIn.target;
-    newEdge->m_dCost = edgeIn.cost;
-    newEdge->m_dReverseCost = edgeIn.reverse_cost;
 
-    if(edgeIn.id > max_edge_id)
-    {
+    GraphEdgeInfo newEdge(edgeIn.id, m_vecEdgeVector.size(),
+            edgeIn.source, edgeIn.target,edgeIn.cost, edgeIn.reverse_cost);
+    newEdge.m_vecStartConnectedEdge.clear();
+    newEdge.m_vecEndConnedtedEdge.clear();
+    newEdge.m_vecRestrictedEdge.clear();
+    newEdge.m_lEdgeID = edgeIn.id;
+    newEdge.m_lEdgeIndex = m_vecEdgeVector.size();    
+    newEdge.m_lStartNode = edgeIn.source;
+    newEdge.m_lEndNode = edgeIn.target;
+    newEdge.m_dCost = edgeIn.cost;
+    newEdge.m_dReverseCost = edgeIn.reverse_cost;
+    if(edgeIn.id > max_edge_id) {
         max_edge_id = edgeIn.id;
     }
 
-    if(newEdge->m_lStartNode > max_node_id)
-    {
-        max_node_id = newEdge->m_lStartNode;
+    if(newEdge.m_lStartNode > max_node_id) { max_node_id = newEdge.m_lStartNode;
     }
-    if(newEdge->m_lEndNode > max_node_id)
-    {
-        max_node_id = newEdge->m_lEndNode;
+
+    if(newEdge.m_lEndNode > max_node_id) { max_node_id = newEdge.m_lEndNode;
     }
 
     //Searching the start node for connectivity
@@ -861,7 +646,7 @@ bool GraphDefinition::addEdge(edge_t edgeIn)
         for(lEdgeIndex = 0; lEdgeIndex < lEdgeCount; lEdgeIndex++)
         {
             long lEdge = itNodeMap->second.at(lEdgeIndex);    
-            connectEdge(*newEdge, *m_vecEdgeVector[lEdge], true);
+            connectEdge(newEdge, m_vecEdgeVector[lEdge], true);
         }
     }
 
@@ -877,19 +662,19 @@ bool GraphDefinition::addEdge(edge_t edgeIn)
         for(lEdgeIndex = 0; lEdgeIndex < lEdgeCount; lEdgeIndex++)
         {
             long lEdge = itNodeMap->second.at(lEdgeIndex);    
-            connectEdge(*newEdge, *m_vecEdgeVector[lEdge], false);
+            connectEdge(newEdge, m_vecEdgeVector[lEdge], false);
         }
     }
 
 
 
     //Add this node and edge into the data structure
-    m_mapNodeId2Edge[edgeIn.source].push_back(newEdge->m_lEdgeIndex);
-    m_mapNodeId2Edge[edgeIn.target].push_back(newEdge->m_lEdgeIndex);
+    m_mapNodeId2Edge[edgeIn.source].push_back(newEdge.m_lEdgeIndex);
+    m_mapNodeId2Edge[edgeIn.target].push_back(newEdge.m_lEdgeIndex);
 
 
     //Adding edge to the list
-    m_mapEdgeId2Index.insert(std::make_pair(newEdge->m_lEdgeID, m_vecEdgeVector.size()));
+    m_mapEdgeId2Index.insert(std::make_pair(newEdge.m_lEdgeID, m_vecEdgeVector.size()));
     m_vecEdgeVector.push_back(newEdge);
 
     //
