@@ -10,7 +10,10 @@
 set -e 
 
 # build pgRouting
-cmake -DWITH_DD=ON 
+cmake  -DPOSTGRESQL_VERSION=$POSTGRESQL_VERSION
 #cmake
 make
 sudo make install
+#cd ..
+
+#./tools/testers/algorithm-tester.pl -pgver $POSTGRESQL_VERSION -ignorenotice
